# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RotateConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'angle': 'float',
        'origin_x': 'int',
        'origin_y': 'int'
    }

    attribute_map = {
        'angle': 'angle',
        'origin_x': 'originX',
        'origin_y': 'originY'
    }

    def __init__(self, angle=None, origin_x=None, origin_y=None):  # noqa: E501
        """RotateConfig - a model defined in Swagger"""  # noqa: E501

        self._angle = None
        self._origin_x = None
        self._origin_y = None
        self.discriminator = None

        self.angle = angle
        self.origin_x = origin_x
        self.origin_y = origin_y

    @property
    def angle(self):
        """Gets the angle of this RotateConfig.  # noqa: E501


        :return: The angle of this RotateConfig.  # noqa: E501
        :rtype: float
        """
        return self._angle

    @angle.setter
    def angle(self, angle):
        """Sets the angle of this RotateConfig.


        :param angle: The angle of this RotateConfig.  # noqa: E501
        :type: float
        """
        if angle is None:
            raise ValueError("Invalid value for `angle`, must not be `None`")  # noqa: E501

        self._angle = angle

    @property
    def origin_x(self):
        """Gets the origin_x of this RotateConfig.  # noqa: E501


        :return: The origin_x of this RotateConfig.  # noqa: E501
        :rtype: int
        """
        return self._origin_x

    @origin_x.setter
    def origin_x(self, origin_x):
        """Sets the origin_x of this RotateConfig.


        :param origin_x: The origin_x of this RotateConfig.  # noqa: E501
        :type: int
        """
        if origin_x is None:
            raise ValueError("Invalid value for `origin_x`, must not be `None`")  # noqa: E501

        self._origin_x = origin_x

    @property
    def origin_y(self):
        """Gets the origin_y of this RotateConfig.  # noqa: E501


        :return: The origin_y of this RotateConfig.  # noqa: E501
        :rtype: int
        """
        return self._origin_y

    @origin_y.setter
    def origin_y(self, origin_y):
        """Sets the origin_y of this RotateConfig.


        :param origin_y: The origin_y of this RotateConfig.  # noqa: E501
        :type: int
        """
        if origin_y is None:
            raise ValueError("Invalid value for `origin_y`, must not be `None`")  # noqa: E501

        self._origin_y = origin_y

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RotateConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RotateConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
